@@ -1,34 +1,16 @@
-package Archive::Zip::Tree;
-
-use strict;
-use vars qw{$VERSION};
-BEGIN {
-	$VERSION = '1.31_04';
-}
-
-use Archive::Zip;
-
-warn(
-"Archive::Zip::Tree is deprecated; its methods have been moved into Archive::Zip."
-) if $^W;
-
-1;
-
-__END__
-
+# $Revision: 1.9 $
+#
 =head1 NAME
 
-Archive::Zip::Tree - (DEPRECATED) methods for adding/extracting trees using Archive::Zip
+Archive::Zip::Tree -- methods for adding/extracting trees using Archive::Zip
 
-=head1 DESCRIPTION
+=head1 SYNOPSIS
 
 This module is deprecated, because all its methods were moved into the main
 Archive::Zip module.
 
 It is included in the distribution merely to avoid breaking old code.
 
-See L<Archive::Zip>.
-
 =head1 AUTHOR
 
 Ned Konz, perl@bike-nomad.com
@@ -45,3 +27,6 @@ L<Archive::Zip>
 
 =cut
 
+warn("Archive::Zip::Tree is deprecated; its methods have been moved into Archive::Zip.") if $^W;
+
+1;
